pub enum HandlerError {
Custom(StatusCode, Option<String>),
Serialization(Error),
}Expand description
A standard error type for handler methods, consisting of an HTTP status code and an optional, more specific error message.
Variants
Custom(StatusCode, Option<String>)
A custom error with a status code and message.
Serialization(Error)
An error that occurred during response serialization.